.. _base:

****************************************
Base classes representing basic elements
****************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: Base
   :synopsis: Base classes.

.. toctree::
   :maxdepth: 2

   saml
   samlp
   metadata
   xmldsig
   xmlenc
   client
   server
   
Module
==========

.. automodule:: saml2
   :members: 

